@@ -98,7 +98,7 @@ namespace snmalloc
      */
     static constexpr uint64_t pal_features = LazyCommit;
 
-    static constexpr size_t page_size = 0x1000;
+    static constexpr size_t page_size = Aal::smallest_page_size;
 
     static void print_stack_trace()
     {
